@@ -16,16 +16,16 @@ def test_document_pattern():
 
     # test if render method works
 
-    doc = dp.render(name=["Real", "Name"], goods=["RealGoods"])
+    doc = dp.render({"name": ["Real", "Name"], "goods": ["RealGoods"]})
 
-    expected_doc_snippet = "[Real Name](name) 的 [RealGoods](goods)"
+    expected_doc_snippet = "[RealName](name)的[RealGoods](goods)"
     result_doc = str(doc)
 
     assert expected_doc_snippet in result_doc
 
     # make sure DocumentPattern is untouched
 
-    expected_pattern_snippet = "<name> 的 <goods>"
+    expected_pattern_snippet = "`name`的`goods`"
     result_pattern = str(dp)
 
     assert expected_pattern_snippet in result_pattern
