@@ -1,6 +1,7 @@
 import copy
 from collections import OrderedDict
 from typing import List
+import itertools
 
 from tokenizer_tools.tagset.offset.analysis.entity_placeholder import EntityPlaceholder
 from tokenizer_tools.tagset.offset.document import Document
@@ -68,7 +69,7 @@ class DocumentPattern(Document):
     def get_placeholders(self) -> List[EntityPlaceholder]:
         return [i for i in self.span_set if isinstance(i, EntityPlaceholder)]
 
-    def render(self, **kwargs) -> Document:
+    def render(self, kwargs) -> Document:
         # TODO: compute as stream of block will be more readable
 
         result_doc = self._copy_structure_as_doc()
@@ -99,6 +100,24 @@ class DocumentPattern(Document):
 
         return result_doc
 
+    def batch_render(self, kwargs):
+        doc_list = []
+        placeholder_names = [i.entity for i in self.get_placeholders()]
+        pattern_specific_dictionary = {i: kwargs[i] for i in placeholder_names}
+
+        instance_list_variable = list(itertools.product(*pattern_specific_dictionary.values()))
+
+        for instance_variable in instance_list_variable:
+            instance_mapping = dict(
+                zip(pattern_specific_dictionary.keys(),
+                    instance_variable))
+
+            doc = self.render(instance_mapping)
+
+            doc_list.append(doc)
+
+        return doc_list
+
     def __hash__(self):
         return hash(tuple(self.text))
 
@@ -109,9 +128,9 @@ class DocumentPattern(Document):
         text_with_annotation = copy.deepcopy(self.text)
         for span in self.span_set:
             start_token = text_with_annotation[span.start]
-            text_with_annotation[span.start] = "<{}".format(start_token)
+            text_with_annotation[span.start] = "`{}".format(start_token)
 
             end_token = text_with_annotation[span.end - 1]
-            text_with_annotation[span.end - 1] = "{}>".format(end_token)
+            text_with_annotation[span.end - 1] = "{}`".format(end_token)
 
-        return " ".join(text_with_annotation)
+        return "".join(text_with_annotation)
